# Fairness-in-AI
Detecting Bias and ensuring Fairness in AI solutions

# Install spacy dependency to run this package
pip install https://huggingface.co/d4data/en_pipeline/resolve/main/en_pipeline-any-py3-none-any.whl
